@@ -20,13 +20,12 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02111-1301  USA
  */
 
-#include <glib.h>
 #include <string.h>
-#ifdef _WIN32
-#include "internal.h"
-#endif
-#include "debug.h"
 
+#include <glib.h>
+
+#include "sipmsg.h"
+#include "sipe-backend.h"
 #include "sipe-sign.h"
 
 static gchar * const empty_string = "";
@@ -35,12 +34,12 @@ void sipmsg_breakdown_parse(struct sipmsg_breakdown * msg, gchar * realm, gchar
 {
 	const gchar * hdr;
 	if (msg == NULL || msg->msg == NULL) {
-		purple_debug(PURPLE_DEBUG_MISC, "sipmsg_breakdown_parse msg or msg->msg is NULL", "\n");
+		SIPE_DEBUG_INFO_NOFORMAT("sipmsg_breakdown_parse msg or msg->msg is NULL");
 		return;
 	}
 
 	msg->rand = msg->num = msg->realm = msg->target_name =
-		msg->cseq = msg->from_url = msg->from_tag = msg->to_url = msg->to_tag = 
+		msg->cseq = msg->from_url = msg->from_tag = msg->to_url = msg->to_tag =
 		msg->p_assertet_identity_sip_uri = msg->p_assertet_identity_tel_uri = empty_string;
 	msg->call_id = msg->expires = empty_string;
 
@@ -87,9 +86,9 @@ void sipmsg_breakdown_parse(struct sipmsg_breakdown * msg, gchar * realm, gchar
 	}
 	if (NULL != hdr) {
 		gchar *tmp = sipmsg_find_part_of_header(hdr, "<", ">", empty_string);
-		if (g_str_has_prefix(tmp, "sip:")) {
+		if (g_ascii_strncasecmp(tmp, "sip:", 4) == 0) {
 			msg->p_assertet_identity_sip_uri = tmp;
-		} else if (g_str_has_prefix(tmp, "tel:")){
+		} else if (g_ascii_strncasecmp(tmp, "tel:", 4) == 0){
 			msg->p_assertet_identity_tel_uri = tmp;
 		} else {
 			g_free(tmp);
@@ -143,7 +142,7 @@ sipmsg_breakdown_get_string(int version,
 	gchar *response_str;
 	gchar *msg;
 	if (msgbd->realm == empty_string || msgbd->realm == NULL) {
-		purple_debug(PURPLE_DEBUG_MISC, "sipe", "realm NULL, so returning NULL signature string\n");
+		SIPE_DEBUG_INFO_NOFORMAT("realm NULL, so returning NULL signature string");
 		return NULL;
 	}
 
