@@ -68,7 +68,7 @@ struct sipmsg *sipmsg_parse_header(const gchar *header) {
 		return NULL;
 	}
 	if(strstr(parts[0],"SIP") || strstr(parts[0],"HTTP")) { /* numeric response */
-		msg->method = g_strdup(parts[2]);
+		msg->responsestr = g_strdup(parts[2]);
 		msg->response = strtol(parts[1],NULL,10);
 	} else { /* request */
 		msg->method = g_strdup(parts[0]);
@@ -76,7 +76,7 @@ struct sipmsg *sipmsg_parse_header(const gchar *header) {
 		msg->response = 0;
 	}
 	g_strfreev(parts);
-	if (sipe_utils_parse_lines(&msg->headers,lines + 1) == FALSE) {
+	if (sipe_utils_parse_lines(&msg->headers, lines + 1, ":") == FALSE) {
 		g_strfreev(lines);
 		sipmsg_free(msg);
 		return NULL;
@@ -90,7 +90,6 @@ struct sipmsg *sipmsg_parse_header(const gchar *header) {
 	}
 	if(msg->response) {
 		const gchar *tmp;
-		g_free(msg->method);
 		tmp = sipmsg_find_header(msg, "CSeq");
 		if(!tmp) {
 			/* SHOULD NOT HAPPEN */
@@ -104,6 +103,38 @@ struct sipmsg *sipmsg_parse_header(const gchar *header) {
 	return msg;
 }
 
+struct sipmsg *sipmsg_copy(const struct sipmsg *other) {
+	struct sipmsg *msg = g_new0(struct sipmsg, 1);
+	GSList *list;
+
+	msg->response		= other->response;
+	msg->responsestr	= g_strdup(other->responsestr);
+	msg->method		= g_strdup(other->method);
+	msg->target		= g_strdup(other->target);
+
+	list = other->headers;
+	while(list) {
+		struct sipnameval *elem = list->data;
+		sipmsg_add_header_now(msg, elem->name, elem->value);
+		list = list->next;
+	}
+
+	list = other->new_headers;
+	while(list) {
+		struct sipnameval *elem = list->data;
+		sipmsg_add_header(msg, elem->name, elem->value);
+		list = list->next;
+	}
+
+	msg->bodylen	= other->bodylen;
+	msg->body	= g_memdup(other->body, other->bodylen);
+	msg->signature	= g_strdup(other->signature);
+	msg->rand	= g_strdup(other->rand);
+	msg->num	= g_strdup(other->num);
+
+	return msg;
+}
+
 char *sipmsg_to_string(const struct sipmsg *msg) {
 	GSList *cur;
 	GString *outstr = g_string_new("");
@@ -238,6 +269,7 @@ void sipmsg_free(struct sipmsg *msg) {
 	g_free(msg->signature);
 	g_free(msg->rand);
 	g_free(msg->num);
+	g_free(msg->responsestr);
 	g_free(msg->method);
 	g_free(msg->target);
 	g_free(msg->body);
@@ -447,10 +479,11 @@ struct html_message_data {
 };
 
 static void get_html_message_mime_cb(gpointer user_data,
-				     const gchar *type,
+				     const GSList *fields,
 				     const gchar *body,
 				     gsize length)
 {
+	const gchar *type = sipe_utils_nameval_find(fields, "Content-Type");
 	struct html_message_data *data = user_data;
 
 	if (!data->preferred) {
